@@ -334,18 +334,6 @@ sub _fix_value
    return $value;
 }
 
-=pod
-
-sub _get_pk_for_related {
-    my ( $self, $object, $relation ) = @_;
-
-    my $source = $object->result_source;
-    my $result_source = $self->_get_related_source( $source, $relation );
-    return $result_source->primary_columns;
-}
-
-=cut
-
 sub _get_related_source {
     my ( $self, $source, $name ) = @_;
 
@@ -366,6 +354,9 @@ For fields that are marked "unique", checks the database for uniqueness.
 
 =cut
 
+# this needs to be rewritten to be called at the field level
+# right now it will only work on fields immediately contained
+# by the form
 sub validate_unique
 {
    my ($self) = @_;
@@ -489,20 +480,6 @@ sub resultset
    return $self->schema->resultset( $self->source_name || $self->item_class );
 }
 
-=pod
-
-sub compute_model_stuff {
-    my ( $self, $field, $source ) = @_;
-    if( ! $source ){
-        return if !$self->schema;
-        $source = $self->source;
-    }
-    return $self->_get_related_source( $source, $field->accessor );
-}
-
-=cut
-
-
 sub new_lookup_options
 {
    my ( $self, $field, $accessor_path ) = @_;
